#[repr(u8)]pub enum TcmWwaitEn {
TCM_WWAIT_EN_0 = 0,
TCM_WWAIT_EN_1 = 1,
}Variants
TCM_WWAIT_EN_0 = 0
TCM write fast mode: Write RAM accesses are expected to be finished in 1-cycle.
TCM_WWAIT_EN_1 = 1
TCM write wait mode: Write RAM accesses are expected to be finished in 2-cycles.
Implementations
Sourceimpl TcmWwaitEn
impl TcmWwaitEn